@@ -1,20 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2022 A S Lewis
+# Copyright (C) 2019-2025 A S Lewis
 #
-# This program is free software: you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 2.1 of the License, or (at your option)
+# any later version.
 #
 # This program is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 # details.
 #
-# You should have received a copy of the GNU General Public License along with
-# this program. If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 
 """Dialogue manager classes."""
@@ -33,7 +33,7 @@ import threading
 
 
 # Import our modules
-import utils
+import ttutils
 
 
 # Classes
@@ -106,7 +106,7 @@ class DialogueManager(threading.Thread):
                 'data'. If it does, the corresponding value is passed to the
                 mainapp.TartubeApp function as an argument
 
-        Returns:
+        Return values:
 
             Gtk.MessageDialog window
 
@@ -127,7 +127,7 @@ class DialogueManager(threading.Thread):
         #   length per line
         mod_list = []
         for line in line_list:
-            mod_list.append(utils.tidy_up_long_string(line, 40))
+            mod_list.append(ttutils.tidy_up_long_string(line, 40))
 
         # Finally combine everything into a single string, as before
         double = '\n\n'
@@ -181,7 +181,7 @@ class DialogueManager(threading.Thread):
                 'data'. If it does, the corresponding value is passed to the
                 mainapp.TartubeApp function as an argument
 
-        Returns:
+        Return values:
 
             Gtk.MessageDialog window
 
@@ -236,7 +236,7 @@ class DialogueManager(threading.Thread):
                 not specified, then the file chooser is opened in Tartube's
                 data directory
 
-        Returns:
+        Return values:
 
             Gtk.MessageDialog window
 
