@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2023 A S Lewis
+# Copyright (C) 2019-2025 A S Lewis
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -33,7 +33,7 @@ import subprocess
 
 # Import our modules
 import mainapp
-import utils
+import ttutils
 
 
 # Classes
@@ -72,7 +72,7 @@ class FFmpegManager(object):
     # Public class methods
 
 
-    def convert_webp(self, thumbnail_filename):
+    def convert_webp(self, thumbnail_filename, retain_flag=False):
 
         """Called by mainapp.TartubeApp.update_video_when_file_found(),
         downloads.VideoDownloader.confirm_sim_video() and
@@ -96,6 +96,12 @@ class FFmpegManager(object):
             thumbnail_filename (str): Full path to the webp file to be
                 converted to jpg
 
+        Optional args:
+
+            retain_flag (bool): True if the original 'thumbnail_filename' file
+                should be retained after the conversion, regardless of the
+                value of mainapp.TartubeApp settings
+
         Return values:
 
             False if an attempted conversion fails, or True otherwise
@@ -112,8 +118,6 @@ class FFmpegManager(object):
         if self.app_obj.ffmpeg_convert_webp_flag \
         and self.app_obj.ffmpeg_retain_webp_flag:
             retain_flag = True
-        else:
-            retain_flag = False
 
         # Correct extension for .webp files with the wrong extension
         #   (youtube-dl #25687, #25717)
@@ -288,7 +292,7 @@ class FFmpegManager(object):
     def is_webp(self, path):
 
         """Called by self.convert_webp() and
-        utils.find_thumbnail_webp_intact_or_broken().
+        ttutils.find_thumbnail_webp_intact_or_broken().
 
         Adapted from youtube-dl/youtube-dl/postprocessor/embedthumbnail.py.
 
@@ -311,7 +315,7 @@ class FFmpegManager(object):
     def is_mislabelled_webp(self, path):
 
         """Called by self.convert_webp() and
-        utils.find_thumbnail_webp_intact_or_broken().
+        ttutils.find_thumbnail_webp_intact_or_broken().
 
         Adapted from self.is_webp().
 
@@ -465,8 +469,12 @@ class FFmpegManager(object):
 
         stdout, stderr = p.communicate()
         if p.returncode != 0:
-            stderr = stderr.decode(utils.get_encoding(), 'replace')
-            return [ False, stderr.strip().splitlines()[-1] ]
+
+            if stderr:
+                stderr = stderr.decode(ttutils.get_encoding(), 'replace')
+                return [ False, stderr.strip().splitlines()[-1] ]
+            else:
+                return [ False, '<unspecified ffmpeg_tartube.py error>' ]
 
         else:
             return [ self.try_utime(out_path, oldest_mtime, oldest_mtime), '' ]
@@ -513,8 +521,12 @@ class FFmpegManager(object):
 
         stdout, stderr = p.communicate()
         if p.returncode != 0:
-            stderr = stderr.decode(utils.get_encoding(), 'replace')
-            return [ False, stderr.strip().splitlines()[-1] ]
+
+            if stderr:
+                stderr = stderr.decode(ttutils.get_encoding(), 'replace')
+                return [ False, stderr.strip().splitlines()[-1] ]
+            else:
+                return [ False, '<unspecified ffmpeg_tartube.py error>' ]
 
         else:
             return [ self.try_utime(source_path, mod_time, mod_time), '' ]
@@ -553,6 +565,9 @@ class FFmpegOptionsManager(object):
         extra_cmd_string (str): A string of extra FFmpeg options, to be applied
             to the system command (if an empty string, nothing is added)
 
+        extra_override_flag (bool): If True, those extra options are the only
+            options used, overriding all of the options below
+
     OPTIONS (FILE TAB)
 
         add_end_filename (str): A string to be added to the end of the
@@ -743,6 +758,7 @@ class FFmpegOptionsManager(object):
         self.options_dict = {
             # NAME TAB
             'extra_cmd_string': '',
+            'extra_override_flag': False,
             # FILE TAB
             'add_end_filename': '',
             'regex_match_filename': '',
@@ -871,7 +887,7 @@ class FFmpegOptionsManager(object):
         #   single item (just as we do for youtube-dl download options)
         extra_cmd_string = options_dict['extra_cmd_string']
         if extra_cmd_string != '':
-            extra_cmd_list = utils.parse_options(extra_cmd_string)
+            extra_cmd_list = ttutils.parse_options(extra_cmd_string)
         else:
             extra_cmd_list = []
 
@@ -926,7 +942,8 @@ class FFmpegOptionsManager(object):
                     return None, None, []
 
             # Find the video's thumbnail
-            source_thumb_path = utils.find_thumbnail(app_obj, video_obj, True)
+            source_thumb_path = \
+            ttutils.find_thumbnail(app_obj, video_obj, True)
             if source_thumb_path is None and input_mode == 'thumb':
                 # Return an empty list; there is nothing for FFmpeg to convert
                 return None, None, []
@@ -992,10 +1009,35 @@ class FFmpegOptionsManager(object):
                 os.path.join(output_dir, output_file),
             )
 
+        # Special case: use only the options specified by 'extra_cmd_string'
+        if options_dict['extra_override_flag'] is True:
+
+            return_list.append(binary)
+            return_list.append('-y')
+            return_list.append('-i')
+
+            if input_mode == 'video':
+                return_list.append(source_video_path)
+            else:
+                return_list.append(source_thumb_path)
+
+            if extra_cmd_list:
+                return_list.extend(extra_cmd_list)
+
+            return_list.extend(
+                [
+                    app_obj.ffmpeg_manager_obj._ffmpeg_filename_argument(
+                        output_path,
+                    ),
+                ],
+            )
+
+            return source_video_path, output_path, return_list
+
         # Special case: when called from config.FFmpegOptionsEditWin, then show
         #   a specimen system command resembling the one that will eventually
         #   be generated by FFmpegManager.run_ffmpeg_multiple_files()
-        if app_obj.ffmpeg_simple_options_flag \
+        if app_obj.simple_ffmpeg_options_flag \
         and video_obj is None \
         and output_mode != 'split' \
         and output_mode != 'slice':
