@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2023 A S Lewis
+# Copyright (C) 2019-2025 A S Lewis
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -40,7 +40,7 @@ import time
 
 # Import our modules
 import downloads
-import utils
+import ttutils
 # Use same gettext translations
 from mainapp import _
 
@@ -178,7 +178,7 @@ class UpdateManager(threading.Thread):
         # (Since we're sending the system command one argument at a time, we
         #   don't need to retain the double quotes around any single argument
         #   and, in fact, doing so would cause an error)
-        cmd_list = utils.strip_double_quotes(cmd_list)
+        cmd_list = ttutils.strip_double_quotes(cmd_list)
 
         # Create the child process
         info = preexec = None
@@ -592,24 +592,39 @@ class UpdateManager(threading.Thread):
             if ytdl_update_current == 'ytdl_update_pip':
                 ytdl_update_current = 'ytdl_update_pip_no_dependencies'
 
-            elif ytdl_update_current == 'ytdl_update_pip3' \
-            or ytdl_update_current == 'ytdl_update_pip3_recommend':
+            elif ytdl_update_current == 'ytdl_update_pip3':
                 ytdl_update_current = 'ytdl_update_pip3_no_dependencies'
 
+            elif ytdl_update_current == 'ytdl_update_pipx':
+                ytdl_update_current = 'ytdl_update_pipx_no_dependencies'
+
             elif ytdl_update_current == 'ytdl_update_win_64':
                 ytdl_update_current = 'ytdl_update_win_64_no_dependencies'
 
             elif ytdl_update_current == 'ytdl_update_win_32':
                 ytdl_update_current = 'ytdl_update_win_32_no_dependencies'
 
+        # For Tartube's MS Windows portable version, when the whole
+        #   installation folder is moved to a new location in the filesystem,
+        #   youtube-dl must be uninstalled, then reinstalled
+        # Rather than trying to distinguish the portable and non-portable
+        #   versions, just do this for all MS Windows users with default
+        #   settings
+        if os.name == 'nt' and self.wiz_win_obj is None and (
+            ytdl_update_current == 'ytdl_update_win_64' \
+            or ytdl_update_current == 'ytdl_update_win_64_no_dependencies' \
+            or ytdl_update_current == 'ytdl_update_win_32' \
+            or ytdl_update_current == 'ytdl_update_win_32_no_dependencies'
+        ):
+            self.uninstall_ytdl(downloader, ytdl_update_current)
+
         # Prepare a system command...
         if os.name == 'nt' \
         and ytdl_update_current == 'ytdl_update_custom_path' \
-        and re.search('\.exe$', self.app_obj.ytdl_path):
+        and re.search(r'\.exe$', self.app_obj.ytdl_path):
             # Special case: on MS Windows, a custom path may point at an .exe,
-            #   therefore 'python3' must be removed from the system command
-            #   (we can't run 'python3.exe youtube-dl.exe' or anything like
-            #   that)
+            #   therefore 'python3' must be removed from the system command (we
+            #   can't run 'python3.exe youtube-dl.exe' or anything like that)
             cmd_list = [self.app_obj.ytdl_path, '-U']
 
         else:
@@ -622,7 +637,7 @@ class UpdateManager(threading.Thread):
             arg = self.app_obj.check_downloader(arg, self.wiz_win_obj)
             # Convert a path beginning with ~ (not on MS Windows)
             if os.name != 'nt':
-                arg = re.sub('^\~', os.path.expanduser('~'), arg)
+                arg = re.sub(r'^\~', os.path.expanduser('~'), arg)
 
             mod_list.append(arg)
 
@@ -670,8 +685,11 @@ class UpdateManager(threading.Thread):
             self.install_ytdl_write_output(msg)
 
         # Operation complete. self.success_flag is checked by
-        #   mainapp.TartubeApp.update_manager_finished
-        if not self.stderr_list:
+        #   mainapp.TartubeApp.update_manager_finished()
+        # We consider the operation successful if there were no errors, or if
+        #   intercept_version_from_stdout() detected a message like
+        #   'Successfully installed...'
+        if not self.success_flag and not self.stderr_list:
             self.success_flag = True
 
         # Show a confirmation in the the Output tab (or wizard window textview)
@@ -685,6 +703,78 @@ class UpdateManager(threading.Thread):
         )
 
 
+    def uninstall_ytdl(self, downloader, ytdl_update_current):
+
+        """Called by self.install_ytdl().
+
+        Uninstall youtube-dl, before reinstalling/updating it.
+
+        Args:
+
+            downloader (str): The value returned by the call to
+                mainapp.TartubeApp.self.app_obj.get_downloader(), e.g.
+                'youtube-dl'
+
+            ytdl_update_current (str): Either the current value of
+                mainapp.TartubeApp.ytdl_update_current, or an overriding
+                value chosen by the calling function
+
+        """
+
+        # Prepare a system command...
+        cmd_list = [
+            '..\\ytdl-venv\\bin\\python3.exe',
+            '-m',
+            'pip',
+            'uninstall',
+            '--yes',
+            downloader,
+        ]
+
+        # ...and display it in the Output tab (if required)
+        self.install_ytdl_write_output(
+            ' '.join(cmd_list),
+            True,                   # A system command, not a message
+        )
+
+        # Create a new child process using that command...
+        self.create_child_process(cmd_list)
+        # ...and set up the PipeReader objects to read from the child process
+        #   STDOUT and STDERR
+        if self.child_process is not None:
+            self.stdout_reader.attach_fh(self.child_process.stdout)
+            self.stderr_reader.attach_fh(self.child_process.stderr)
+
+        while self.is_child_process_alive():
+
+            # Pause a moment between each iteration of the loop (we don't want
+            #   to hog system resources)
+            time.sleep(self.sleep_time)
+
+            # Read from the child process STDOUT and STDERR, in the correct
+            #   order, until there is nothing left to read
+            while self.read_ytdl_child_process(downloader):
+                pass
+
+        # (Generate our own error messages for debugging purposes, in certain
+        #   situations)
+        if self.child_process is None:
+
+            msg = _('Update did not start')
+
+            self.stderr_list.append(msg)
+            self.install_ytdl_write_output(msg)
+
+        elif self.child_process.returncode > 0:
+
+            msg = _('Child process exited with non-zero code: {}').format(
+                self.child_process.returncode,
+            )
+
+            self.stderr_list.append(msg)
+            self.install_ytdl_write_output(msg)
+
+
     def install_ytdl_write_output(self, msg, system_cmd_flag=False):
 
         """Called by self.install_ytdl().
@@ -734,18 +824,19 @@ class UpdateManager(threading.Thread):
         """
 
         regex_list = [
-            'Requirement already up\-to\-date\: ' + downloader \
-            + ' in .*\(([^\(\)]+)\)\s*$',
-            'Requirement already satisfied\: ' + downloader \
-            + ' in .*\(([^\(\)]+)\)\s*$',
-            'yt-dlp is up to date \(([^\(\)]+)\)\s*$',
-            'Successfully installed ' + downloader + '\-([^\(\)]+)\s*$',
+            r'Requirement already up\-to\-date\: ' + downloader \
+            + r' in .*\(([^\(\)]+)\)\s*$',
+            r'Requirement already satisfied\: ' + downloader \
+            + r' in .*\(([^\(\)]+)\)\s*$',
+            r'yt-dlp is up to date \(([^\(\)]+)\)\s*$',
+            r'Successfully installed ' + downloader + r'\-([^\(\)]+)\s*$',
         ]
 
         for regex in regex_list:
             substring = re.search(regex, stdout)
             if substring:
                 self.ytdl_version = substring.group(1)
+                self.success_flag = True
                 return
 
 
@@ -808,7 +899,7 @@ class UpdateManager(threading.Thread):
         data = mini_list[2].rstrip()
         # On MS Windows we use cp1252, so that Tartube can communicate with the
         #   Windows console
-        data = data.decode(utils.get_encoding(), 'replace')
+        data = data.decode(ttutils.get_encoding(), 'replace')
 
         # STDOUT
         if mini_list[1] == 'stdout':
@@ -822,7 +913,7 @@ class UpdateManager(threading.Thread):
 
             # Ignore pacman warning messages, e.g. 'warning: dependency cycle
             #   detected:'
-            if data and not re.search('^warning\:', data):
+            if data and not re.search(r'^warning\:', data):
 
                 self.stderr_list.append(data)
 
@@ -872,7 +963,7 @@ class UpdateManager(threading.Thread):
         data = mini_list[2].rstrip()
         # On MS Windows we use cp1252, so that Tartube can communicate with the
         #   Windows console
-        data = data.decode(utils.get_encoding(), 'replace')
+        data = data.decode(ttutils.get_encoding(), 'replace')
 
         # STDOUT
         if mini_list[1] == 'stdout':
@@ -886,7 +977,7 @@ class UpdateManager(threading.Thread):
 
             # Ignore pacman warning messages, e.g. 'warning: dependency cycle
             #   detected:'
-            if data and not re.search('^warning\:', data):
+            if data and not re.search(r'^warning\:', data):
 
                 self.stderr_list.append(data)
 
@@ -936,7 +1027,7 @@ class UpdateManager(threading.Thread):
         data = mini_list[2].rstrip()
         # On MS Windows we use cp1252, so that Tartube can communicate with the
         #   Windows console
-        data = data.decode(utils.get_encoding(), 'replace')
+        data = data.decode(ttutils.get_encoding(), 'replace')
 
         # STDOUT
         if mini_list[1] == 'stdout':
@@ -950,7 +1041,7 @@ class UpdateManager(threading.Thread):
 
             # Ignore pacman warning messages, e.g. 'warning: dependency cycle
             #   detected:'
-            if data and not re.search('^warning\:', data):
+            if data and not re.search(r'^warning\:', data):
 
                 self.stderr_list.append(data)
 
@@ -1004,7 +1095,7 @@ class UpdateManager(threading.Thread):
         data = mini_list[2].rstrip()
         # On MS Windows we use cp1252, so that Tartube can communicate with the
         #   Windows console
-        data = data.decode(utils.get_encoding(), 'replace')
+        data = data.decode(ttutils.get_encoding(), 'replace')
 
         # STDOUT
         if mini_list[1] == 'stdout':
@@ -1041,7 +1132,8 @@ class UpdateManager(threading.Thread):
             #   received
             if not re.search('DEPRECATION', data) \
             and not re.search('You are using pip version', data) \
-            and not re.search('You should consider upgrading', data):
+            and not re.search('You should consider upgrading', data) \
+            and not re.search('Skipping .* as it is not installed', data):
                 self.stderr_list.append(data)
 
             # Show command line output in the Output tab (or wizard window
